Package 'free1way.docreg'

Title: Additional Documentation and Regression Tests for 'stats::free1way()'
Description: Function 'stats::free1way()' implements semiparametrically efficient population- and permutation-based inference in distribution-free stratified K-sample oneway layouts. This package provides additional documentation, including a detailed description of the implementation, and serves as a home for extensive regression tests.
Authors: Torsten Hothorn [aut, cre], Kurt Hornik [aut], Frank E Harrell Jr [ctb]
Maintainer: Torsten Hothorn <[email protected]>
License: GPL-2
Version: 1.0-0
Built: 2026-05-22 13:41:18 UTC
Source: https://github.com/cran/free1way.docreg

Help Index