| Title: | Additional Documentation and Regression Tests for 'stats::free1way()' |
| Version: | 1.0-3 |
| Description: | Function 'stats::free1way()' implements semiparametrically efficient population- and permutation-based inference in distribution-free stratified K-sample oneway layouts. This package provides additional documentation, including a detailed description of the implementation, and serves as a home for extensive regression tests. |
| Depends: | R (≥ 4.6.0), stats, graphics, bibtex |
| Suggests: | Matrix, rms, survival, MASS, tram, coin, multcomp, TH.data, Hmisc, latticeExtra, daewr |
| License: | GPL-2 |
| URL: | https://codeberg.org/thothorn/coin/ |
| BugReports: | https://codeberg.org/thothorn/coin/issues |
| NeedsCompilation: | no |
| Packaged: | 2026-09-08 13:33:24 UTC; hothorn |
| Author: | Torsten Hothorn [aut, cre], Kurt Hornik [aut], Frank E Harrell Jr [ctb] |
| Maintainer: | Torsten Hothorn <Torsten.Hothorn@R-project.org> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-08 16:00:02 UTC |